summaryrefslogtreecommitdiffstats
path: root/sys/dev/mii/ciphy.c
diff options
context:
space:
mode:
authorraj <raj@FreeBSD.org>2008-03-03 18:44:33 +0000
committerraj <raj@FreeBSD.org>2008-03-03 18:44:33 +0000
commit092ca8c4fd3fba9163ca11503705a4a3d721574e (patch)
tree6a54a1704a93331d9fd39707d21d4ff631ffa4bb /sys/dev/mii/ciphy.c
parentddcbd7a1c933343caf6997ea48416ce7af082d83 (diff)
downloadFreeBSD-src-092ca8c4fd3fba9163ca11503705a4a3d721574e.zip
FreeBSD-src-092ca8c4fd3fba9163ca11503705a4a3d721574e.tar.gz
Recognize the quad-port Cicada (Vitesse) CS8204 10/100/1000TX PHY.
This PHY is found on many embedded development boards: among others MPC8555CDS evaluation systems use it. Approved by: cognet (mentor) MFp4: e500
Diffstat (limited to 'sys/dev/mii/ciphy.c')
-rw-r--r--sys/dev/mii/ciphy.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/sys/dev/mii/ciphy.c b/sys/dev/mii/ciphy.c
index 4ad1a6c..3791ed5 100644
--- a/sys/dev/mii/ciphy.c
+++ b/sys/dev/mii/ciphy.c
@@ -34,7 +34,7 @@
__FBSDID("$FreeBSD$");
/*
* Driver for the Cicada CS8201 10/100/1000 copper PHY.
*/
#include <sys/param.h>
@@ -91,6 +91,7 @@ static const struct mii_phydesc ciphys[] = {
MII_PHY_DESC(CICADA, CS8201),
MII_PHY_DESC(CICADA, CS8201A),
MII_PHY_DESC(CICADA, CS8201B),
+ MII_PHY_DESC(CICADA, CS8204),
MII_PHY_DESC(VITESSE, VSC8601),
MII_PHY_END
};
@@ -378,6 +379,7 @@ ciphy_fixup(struct mii_softc *sc)
}
switch (model) {
+ case MII_MODEL_CICADA_CS8204:
case MII_MODEL_CICADA_CS8201:
/* Turn off "aux mode" (whatever that means) */
OpenPOWER on IntegriCloud
@@ -34,7 +34,7 @@
__FBSDID("$FreeBSD$");
/*
- * Driver for the Cicada CS8201 10/100/1000 copper PHY.
+ * Driver for the Cicada CS8201/CS8204 10/100/1000 copper PHY.
*/
#include <sys/param.h>